@@ -50,6 +50,13 @@ def _write_json(data, filename):
         json.dump(data, f, indent=4)
 
 
+def _get_benchmark_path(gdrive_path, model_type, fname="trained_tt.json"):
+    env_fname = "_".join(list(check_env_info().values()))
+    env_path = os.path.join(gdrive_path, env_fname)
+    actual_tt_json_path = os.path.join(env_path, model_type, fname)
+    return actual_tt_json_path
+
+
 def save_benchmark(
         benchmarks_mini: list,
         columns: list,
@@ -70,9 +77,7 @@ def save_benchmark(
     :param gdrive_path: 
     :return: 
     """
-    env_fname = "_".join(list(check_env_info().values()))
-    env_path = os.path.join(gdrive_path, env_fname)
-    actual_tt_json_path = os.path.join(env_path, model_type, "trained_tt.json")
+    actual_tt_json_path = _get_benchmark_path(gdrive_path, model_type)
     _ensure_dir(actual_tt_json_path)
     model_index = None
     if not os.path.exists(actual_tt_json_path) or replace == True:
